@@ -21,7 +21,7 @@ role Gitalist::Git::Object::HasTree {
                                     type => $type,
                                     sha1 => $object,
                                     file => $file,
-                                    project => $self->project,
+                                    repository => $self->repository,
                                   );
         }
         return \@ret;
@@ -42,7 +42,7 @@ Gitalist::Git::Object::HasTree
 
 =head1 SYNOPSIS
 
-    my $tree = Project->get_object($tree_sha1);
+    my $tree = Repository->get_object($tree_sha1);
 
 =head1 DESCRIPTION
 
