@@ -20,7 +20,7 @@ Gitalist::Git::Object::Tree
 
 =head1 SYNOPSIS
 
-    my $tree = Project->get_object($tree_sha1);
+    my $tree = Repository->get_object($tree_sha1);
 
 =head1 DESCRIPTION
 
